@@ -1,9 +1,10 @@
 extern crate rayon;
 extern crate reqwest;
-extern crate robotparser;
+extern crate robotparser_fork;
 extern crate scraper;
 extern crate url;
 extern crate num_cpus;
+extern crate tokio;
 
 /// Configuration structure for `Website`
 pub mod configuration;
@@ -11,3 +12,5 @@ pub mod configuration;
 pub mod page;
 /// A website to crawl
 pub mod website;
+/// Application utils
+pub mod utils;
\ No newline at end of file
