@@ -1,4 +1,3 @@
-use reqwest;
 use scraper::{Html, Selector};
 use url::Url;
 
@@ -15,27 +14,8 @@ pub struct Page {
 
 impl Page {
     /// Instanciate a new page and start to scrape it.
-    pub fn new(url: &str, user_agent: &str) -> Self {
-        let mut body = String::new();
-
-        let client = reqwest::blocking::Client::builder()
-            .user_agent(user_agent)
-            .build()
-            .unwrap();
-
-        match client.get(url).send() {
-            Ok(res) if res.status() == reqwest::StatusCode::OK => match res.text() {
-                Ok(text) => body = text,
-                Err(e) => eprintln!("[error] {}: {}", url, e),
-            },
-            Ok(_) => (),
-            Err(e) => eprintln!("[error] {}: {}", url, e),
-        }
-
-        Self {
-            url: url.to_string(),
-            html: body,
-        }
+    pub fn new(url: &str, html: &str) -> Self {
+        Page::build(url, html)
     }
 
     /// Instanciate a new page without scraping it (used for testing purposes)
@@ -47,8 +27,8 @@ impl Page {
     }
 
     /// URL getter
-    pub fn get_url(&self) -> String {
-        self.url.clone()
+    pub fn get_url(&self) -> &String {
+        &self.url
     }
 
     /// HTML parser
@@ -56,10 +36,6 @@ impl Page {
         Html::parse_document(&self.html)
     }
 
-    pub fn get_plain_html(&self) -> String {
-        self.html.clone()
-    }
-
     /// Find all href links and return them
     pub fn links(&self, domain: &str) -> Vec<String> {
         let mut urls: Vec<String> = Vec::new();
@@ -75,7 +51,7 @@ impl Page {
                 let abs_path = self.abs_path(href);
 
                 if abs_path.as_str().starts_with(domain) {
-                    urls.push(format!("{}", abs_path));
+                    urls.push(abs_path.to_string());
                 }
             }
         }
@@ -95,22 +71,35 @@ impl Page {
 
 #[test]
 fn parse_links() {
-    let page: Page = Page::new("https://choosealicense.com/", "spider/1.1.2");
+    use crate::utils::{Client, fetch_page_html};
+    let client = Client::builder()
+        .user_agent("spider/1.1.2")
+        .build()
+        .unwrap();
+
+    let link_result = "https://choosealicense.com/";
+    let html = fetch_page_html(&link_result, &client).unwrap();
+    let page: Page = Page::new(&link_result, &html);
 
     assert!(
         page.links("https://choosealicense.com")
             .contains(&"https://choosealicense.com/about/".to_string()),
-        format!(
             "Could not find {}. Theses URLs was found {:?}",
             page.url,
             page.links("https://choosealicense.com")
-        )
     );
 }
 
 #[test]
 fn test_abs_path() {
-    let page: Page = Page::new("https://choosealicense.com/", "spider/1.1.2");
+    use crate::utils::{Client, fetch_page_html};
+    let client = Client::builder()
+        .user_agent("spider/1.1.2")
+        .build()
+        .unwrap();
+    let link_result = "https://choosealicense.com/";
+    let html = fetch_page_html(&link_result, &client).unwrap();
+    let page: Page = Page::new(&link_result, &html);
 
     assert_eq!(
         page.abs_path("/page"),
